@@ -10,8 +10,8 @@ import urllib.request
 
 
 MAJOR = "0"
-MINOR = "0"
-MAINTAINENCE = "99"
+MINOR = "1"
+MAINTAINENCE = "03"
 
 
 def version():
@@ -90,7 +90,7 @@ def _read_stream(sock):
 def double_rcvbuf(sock):
     """
     double_rcvbuf doubles socket.SO_RCVBUF
-    until it errors 
+    until it errors
     """
     rcvbuf_size = sock.getsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF)
     while True:
@@ -99,42 +99,38 @@ def double_rcvbuf(sock):
             sock.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, rcvbuf_size)
         except:
             break
-        
 
-def _udp_sock_opts(sock):   
+def _mk_sock():
+    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP)
     double_rcvbuf(sock)
     sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
     if hasattr(socket, "SO_REUSEPORT"):
         sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEPORT, 1)
-    # return sock
+    return sock
 
 
 def _mk_udp_sock(udp_ip, udp_port):
     """
     udp socket setup
     """
-    # sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP)
-
-    _udp_sock_opts(sock)
-    sock.bind((udp_ip, udp_port))
-    return sock
+    udp_sock = _mk_sock()
+    udp_sock.bind((udp_ip, udp_port))
+    return _read_stream(udp_sock)
 
 
-def _mk_mcast_sock(mcast_grp, mcast_port, all_grps=True):
+def _mk_mcast_sock(mcast_grp, mcast_port):
     """
     multicast socket setup
     """
-
-    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP)
-    _udp_sock_opts(sock)
-    if all_grps:
-        sock.bind(("", mcast_port))
-    else:
-        sock.bind((mcast_grp, mcast_port))
-    mreq = struct.pack("4sl", socket.inet_aton(mcast_grp), socket.INADDR_ANY)
-    sock.setsockopt(socket.IPPROTO_IP, socket.IP_ADD_MEMBERSHIP, mreq)
-    return sock
+    mcast_host ="0.0.0.0"
+    mcast_sock = _mk_sock()
+    mcast_sock.setsockopt(
+        socket.IPPROTO_IP,
+        socket.IP_ADD_MEMBERSHIP,
+        socket.inet_aton(mcast_grp) + socket.inet_aton(mcast_host),
+    )
+    mcast_sock.bind((mcast_host,mcast_port))
+    return _read_stream(mcast_sock)
 
 
 def _open_udp(uri):
@@ -143,8 +139,8 @@ def _open_udp(uri):
     """
     udp_ip, udp_port = (uri.split("udp://")[1]).rsplit(":",1)
     udp_port = int(udp_port)
-    udp_sock = _mk_udp_sock(udp_ip, udp_port)
-    return _read_stream(udp_sock)
+    return _mk_udp_sock(udp_ip, udp_port)
+
 
 
 def _open_mcast(uri):
@@ -153,5 +149,4 @@ def _open_mcast(uri):
     """
     mcast_grp, mcast_port = (uri.split("udp://@")[1]).rsplit(":",1)
     mcast_port = int(mcast_port)
-    mcast_sock = _mk_mcast_sock(mcast_grp, mcast_port)
-    return _read_stream(mcast_sock)
+    return _mk_mcast_sock(mcast_grp, mcast_port)
